// src/index.ts
function getHighlightAPI() {
  if (globalThis.highlight === void 0) {
    throw new Error(
      "Your web app must be running in the Highlight app to use this module. Please see https://docs.highlight.ing for more details."
    );
  }
  return globalThis.highlight;
}
function awaitNextTextPrediction(id) {
  const api2 = getHighlightAPI();
  return new Promise((resolve) => {
    const createListener = () => {
      api2.once("onTextPredictionDone", (message) => {
        if (message.id !== id) {
          createListener();
          return;
        }
        resolve();
      });
      api2.once("onTextPredictionUpdate", (message) => {
        if (message.id !== id) {
          createListener();
          return;
        }
        resolve(message.text);
      });
    };
    createListener();
  });
}
var api = {
  appStorage: {
    isHydrated: () => getHighlightAPI().appStorage.isHydrated(),
    whenHydrated: () => getHighlightAPI().appStorage.whenHydrated(),
    all: () => getHighlightAPI().appStorage.all(),
    get: (key) => getHighlightAPI().appStorage.get(key),
    set: (key, value) => getHighlightAPI().appStorage.set(key, value),
    setAll: (value) => getHighlightAPI().appStorage.setAll(value),
    delete: (key) => getHighlightAPI().appStorage.delete(key),
    clear: () => getHighlightAPI().appStorage.clear()
  },
  app: {
    setBackgroundStatus: (status) => getHighlightAPI().app.setBackgroundStatus(status),
    getHotkey: () => getHighlightAPI().app.getHotkey(),
    addListener: (event, listener) => getHighlightAPI().app.addListener(event, listener),
    openApp: (appId) => getHighlightAPI().app.openApp(appId)
  },
  permissions: {
    requestBackgroundPermission: () => getHighlightAPI().permissions.requestBackgroundPermission(),
    requestClipboardReadPermission: () => getHighlightAPI().permissions.requestClipboardReadPermission(),
    requestScreenshotPermission: () => getHighlightAPI().permissions.requestScreenshotPermission()
  },
  user: {
    getFacts: () => getHighlightAPI().user.getFacts(),
    getAudio: (longAudio) => getHighlightAPI().user.getAudio(longAudio),
    getAudioForDuration: (duration) => getHighlightAPI().user.getAudioForDuration(duration),
    setAsrRealtime: (isActive) => getHighlightAPI().user.setAsrRealtime(isActive),
    getMicActivity: (lastNumMs) => getHighlightAPI().user.getMicActivity(lastNumMs),
    getScreenshot: () => getHighlightAPI().user.getScreenshot(),
    getEmail: () => getHighlightAPI().user.getEmail(),
    getContext: () => getHighlightAPI().user.getContext(),
    getClipboardContents: () => getHighlightAPI().user.getClipboardContents(),
    getDisplayScreenshots: () => getHighlightAPI().user.getDisplayScreenshots(),
    getWindows: () => getHighlightAPI().user.getWindows(),
    getWindowScreenshot: (windowTitle) => getHighlightAPI().user.getWindowScreenshot(windowTitle)
  },
  auth: {
    signIn: () => getHighlightAPI().auth.signIn()
  },
  inference: {
    getTextPrediction: async function* (messages) {
      const api2 = getHighlightAPI();
      const id = await api2.internal.getTextPrediction(messages);
      let done = false;
      const onTextPredictionDoneListener = (message) => {
        if (message.id !== id) {
          return;
        }
        done = true;
      };
      api2.addEventListener("onTextPredictionDone", onTextPredictionDoneListener);
      while (!done) {
        const next = await awaitNextTextPrediction(id);
        if (next) {
          yield next;
        }
      }
      api2.removeEventListener("onTextPredictionDone", onTextPredictionDoneListener);
    }
  },
  addEventListener: (event, listener) => {
    getHighlightAPI().addEventListener(event, listener);
  },
  removeEventListener: (event, listener) => {
    getHighlightAPI().removeEventListener(event, listener);
  },
  once: (event, listener) => {
    getHighlightAPI().once(event, listener);
  },
  isRunningInHighlight: () => {
    return globalThis.highlight !== void 0;
  }
};
var src_default = api;
export {
  src_default as default
};
//# sourceMappingURL=index.js.map